@@ -20,6 +20,7 @@ pub struct PaletteFromYaml {
     pub fg: PaletteColorFromYaml,
     pub bg: PaletteColorFromYaml,
     pub black: PaletteColorFromYaml,
+    pub gray: PaletteColorFromYaml,
     pub red: PaletteColorFromYaml,
     pub green: PaletteColorFromYaml,
     pub yellow: PaletteColorFromYaml,
@@ -77,8 +78,9 @@ impl From<PaletteFromYaml> for Palette {
     fn from(yaml: PaletteFromYaml) -> Self {
         Palette {
             fg: yaml.fg.into(),
-            bg: yaml.fg.into(),
+            bg: yaml.bg.into(),
             black: yaml.black.into(),
+            gray: yaml.gray.into(),
             red: yaml.red.into(),
             green: yaml.green.into(),
             yellow: yaml.yellow.into(),
